Stan Math Library: stan/math/prim/scal/err/check_size_match.hpp File Reference

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- File List
- File Members

Namespaces | Functions
check_size_match.hpp File Reference
`#include <boost/type_traits/common_type.hpp>`
`#include <stan/math/prim/scal/err/invalid_argument.hpp>`
`#include <stan/math/prim/scal/meta/likely.hpp>`
`#include <sstream>`
`#include <string>`

Go to the source code of this file.

## Namespaces
| stan
| stan::math
| Matrices and templated mathematical functions.

## Functions
template<typename T_size1 , typename T_size2 >
bool | stan::math::check_size_match (const char *function, const char *name_i, T_size1 i, const char *name_j, T_size2 j)
| Return `true` if the provided sizes match. More...
template<typename T_size1 , typename T_size2 >
bool | stan::math::check_size_match (const char *function, const char *expr_i, const char *name_i, T_size1 i, const char *expr_j, const char *name_j, T_size2 j)
| Return `true` if the provided sizes match. More...

[ Stan Home Page ] © 2011–2016, Stan Development Team.